## intent:greet
- hey
- hello
- hi
- good morning
- good evening
- hey there

## intent:mood_happy
- perfect
- very good
- great
- amazing
- wonderful
- I am feeling very good
- I am great
- I'm good

## intent:mood_unhappy
- sad
- very sad
- unhappy
- bad
- very bad
- awful
- terrible
- not very good
- extremely sad
- so sad

## intent:goodbye
- bye
- goodbye
- see you around
- see you later